@@ -1,6 +1,6 @@
 #  MIT License
 #
-#  Copyright (c) 2017-2021 TileDB Inc.
+#  Copyright (c) 2017-2022 TileDB Inc.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -63,6 +63,28 @@ tiledb_filter_list <- function(filters = c(), ctx = tiledb_get_context()) {
   return(new("tiledb_filter_list", ptr = ptr))
 }
 
+# internal function returning text use here and in other higher-level show() methods
+.as_text_filter_list <- function(object) {
+    n <- nfilters(object)
+    if (n == 0) return("")
+    txt <- "tiledb_filter_list(c("
+    for (i in seq_len(n)) {
+        ## The i-1 is necessary as these are 0-up indexed (unusual for R, a leftover from older code)
+        txt <- paste0(txt, .as_text_filter(object[i-1]), if (i == n) ")" else ", ")
+    }
+    txt <- paste0(txt, ")")
+}
+
+#' Prints a filter_list object
+#'
+#' @param object A filter_list object
+#' @export
+setMethod("show",
+          signature(object = "tiledb_filter_list"),
+          definition = function(object) {
+    cat(.as_text_filter_list(object), "\n")
+})
+
 #' @rdname tiledb_filter_list_set_max_chunk_size
 #' @export
 setGeneric("set_max_chunk_size", function(object, value) standardGeneric("set_max_chunk_size"))
